#!/bin/bash
# Importing the source files into project

if [ -r "$PLATFORM_LOC/scripts/utils.sh" ]; then
	source "$PLATFORM_LOC/scripts/utils.sh"
else
	source "$script_lib_dir/utils.sh"
fi

srcDir=$DOWNLOAD_LOC
srcUrl=$SRC_LOC
srcFilename=${srcUrl##*/}
srcFile="$srcDir/$srcFilename"

require_script scms_utils.sh

# Package to create
: ${projName:=$PACKAGE_ID}

# Default untar strip level
: ${STRIP_LEVEL:=1}

tar_extract() {
	local srcFile="$1"
	local destDir="$2"

	log "Extracting sources into project..."
	log_exec tar xf ${srcFile} -C ${destDir} --strip-components=${STRIP_LEVEL}
}

zip_extract() {
	local srcFile="$1"
	local destDir="$2"
	
	log "Extracting sources into project..."
	log_exec unzip -qq ${srcFile} -d ${destDir}
}

##################################################################
#				
# Unpack/Import the source into future project location 
#
###################################################################
import() {
	local srcUrl="$1"
	local srcFile="$2"
	
	local destDir="${WORKSPACE_LOC}/${projName}"

	if [ -n "$scms_tool" ]; then
		if ${scms_tool}_import "$srcUrl" "$srcFile" "$destDir"; then
			return 0
		else
			return 1
		fi
	fi

	# Create project directory
	log_exec mkdir -p ${destDir}

	case $srcUrl in
		*.tar.*)
			tar_extract ${srcFile} ${destDir}
			;;
		*.zip)
			zip_extract ${srcFile} ${destDir}
			;;
		*.bin)
			# TODO
				log "Binary Format"
				log_exec chmod +x ${srcFile}
				binFile=$(basename ${srcFile})
				binFolder=$(basename ${srcFile} .bin)
				echo ${srcDir}
				cd ${srcDir}
				log_exec /bin/bash ${binFile} --auto-accept --force
				log_exec cp -r ${binFolder}/* ${destDir}/
				log_exec rm -rf ${binFolder}
				log "${binFolder} extracted in ${destDir}/"
			;;
		*:*)
			# TODO
			fatal 1 "URL scheme for '$srcUrl' not implemented yet"
			;;
		*)
			if [ "$srcUrl" != "empty" ]; then
				tar_extract ${srcDir}/${projName}.tar.bz2 ${destDir}
			fi
			;;
	esac
} 

do_buildstep_prepend

import ${srcUrl} ${srcFile}

do_buildstep_append
